/*=============================================================================
 * parser for CSP instances represented in XML format
 * 
 * Copyright (c) 2008 Olivier ROUSSEL (olivier.roussel <at> cril.univ-artois.fr)
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *=============================================================================
 */

#include "XMLParser_libxml2.hh"
#include "CSPNormalizerCallback.hh"

using namespace CSPXMLParser;


int main(int argc, char **argv)
{
  CSPNormalizerCallback cb; // my interface between the parser and the solver

  if (argc!=2)
  {
    cout << "syntax: " << argv[0] << " CSPFile.xml\n"
	 << "  this program is a just a demonstration to illustrate how to use the CSP XML parser\n"
	 << endl;
    exit(1);
  }

  try
  {
    XMLParser_libxml2<CSPNormalizerCallback,NormalizerASTFactory> parser(cb);

    parser.setPreferredExpressionRepresentation(PREFIX);

    // first pass
    cb.firstPass();
    parser.parse(argv[1]); // parse the input file

    // second pass
    cb.secondPass();
    parser.parse(argv[1]); 
  }
  catch (exception &e)
  {
    cout.flush();
    cerr << "\n\tUnexpected exception :\n";
    cerr << "\t" << e.what() << endl;
    exit(1);
  }

  return 0;
}
