/*=============================================================================
 * parser for CSP instances represented in XML format
 * 
 * Copyright (c) 2008 Olivier ROUSSEL (olivier.roussel <at> cril.univ-artois.fr)
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *=============================================================================
 */
#include <iostream>
#include <vector>

#include "CSPInstanceInformationCallback.hh"
#include "XMLParser_libxml2.hh"

using namespace CSPXMLParser;
using namespace std;

int main(int argc, char **argv)
{
  CSPInstanceInformationCallback cb;

  if (argc!=2)
  {
    cout << "usage: " << argv[0] << " <filename>" << endl
	 << "\tprovides some information about a CSP instance" << endl;
    
    exit(1);
  }

  try
  {
    XMLParser_libxml2<> parser(cb);

    int err=parser.parse(argv[1]); // parse the input file and verify

    // if the callback didn't complain, then everything is OK
    if (err!=0)
      cout << "ERROR: parser problems" << endl;
    else
    {
      cout << "nbVar=" << cb.nbVar << ",nbConstr=" << cb.nbConstr 
	   << ",maxConstrArity=" << cb.maxArity << ",maxDomSize=" << cb.maxDomSize
	   << ",nbPredicateConstr=" << cb.nbPredicateConstr
	   << ",nbRelationConstr=" << cb.nbRelationConstr
	   << ",globalConstraints='";

      for(map<string,int>::iterator it=cb.globalConstraints.begin();
	  it!=cb.globalConstraints.end();++it)
      {
	if (it!=cb.globalConstraints.begin())
	  cout << ',';

	cout << (*it).first << "(" << (*it).second << ")";
      }

      cout << "'" << endl;
    }
  }
  catch (exception &e)
  {
    cout.flush();
    cerr << "\n\tUnexpected exception :\n";
    cerr << "\t" << e.what() << endl;
    exit(1);
  }

  return 0;
}
